Overview
========

A simple console script for mirroring git repositories between two remotes.

Usage
-----

```sh
easy_install infi.git_mirror
mirror_git_repository git://gitserver/some-repo.git git@github.com:Infinidat/some-repo.git
```

Checking out the code
=====================

Run the following:

    easy_install -U infi.projector
    projector devenv build
